@@ -443,7 +443,7 @@ class Microservices(BaseClass, ABC):
                     msg.get('data', {})
                 ))
 
-        try:
+        """ try:
             TIME = msg['metadata']['time']
             DATE = None
             IS_Z = TIME.find('Z') > -1
@@ -473,7 +473,7 @@ class Microservices(BaseClass, ABC):
 
         except Exception as e:
             self.logs.warn(
-                'Error al momento de procesar el tiempo del mensaje', e)
+                'Error al momento de procesar el tiempo del mensaje', e) """
 
         # Procesar el mensaje
         try:
